@@ -2636,6 +2636,159 @@ if (argv[0]) {
     returnType.construct(argv[0], &s.v2_10);
 }
 return;
+}
+ },{ 26, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
+    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
+    const auto *aotContext = &c;
+    Q_UNUSED(aotContext);
+    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
+}, 
+    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
+Q_UNUSED(aotContext)
+Q_UNUSED(argv)
+// expression for fillMode at line 167, column 13
+struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
+Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
+void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
+}
+const QQmlPrivate::AOTCompiledContext *aotContext;
+void **argv;
+int v2_2;
+};
+Storage s(aotContext, argv);
+aotContext->setLocals(&s);
+{
+}
+// generate_GetLookup
+#ifndef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+while (!aotContext->getEnumLookup(84, &s.v2_2)) {
+#ifdef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+aotContext->initGetEnumLookup(84, []() { static const auto t = QMetaType::fromName("QQuickImage*"); return t; }().metaObject(), "FillMode", "PreserveAspectFit");
+if (aotContext->engine->hasError()) {
+aotContext->setReturnValueUndefined();
+if (argv[0]) {
+    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickImage::FillMode"); return t; }();
+    returnType.destruct(argv[0]);
+    returnType.construct(argv[0]);
+ }
+return;
+}
+}
+{
+}
+{
+}
+// generate_Ret
+if (argv[0]) {
+    const QMetaType returnType = QMetaType::fromType<int>();
+    returnType.destruct(argv[0]);
+    returnType.construct(argv[0], &s.v2_2);
+}
+return;
+}
+ },{ 28, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
+    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
+    const auto *aotContext = &c;
+    Q_UNUSED(aotContext);
+    argTypes[0] = QMetaType::fromType<double>();
+}, 
+    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
+Q_UNUSED(aotContext)
+Q_UNUSED(argv)
+// expression for preferredWidth at line 156, column 13
+struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
+Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
+void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
+}
+const QQmlPrivate::AOTCompiledContext *aotContext;
+void **argv;
+double v2_0;
+};
+Storage s(aotContext, argv);
+aotContext->setLocals(&s);
+// generate_LoadQmlContextPropertyLookup
+#ifndef QT_NO_DEBUG
+aotContext->setInstructionPointer(2);
+#endif
+while (!aotContext->loadScopeObjectPropertyLookup(93, &s.v2_0)) {
+#ifdef QT_NO_DEBUG
+aotContext->setInstructionPointer(2);
+#endif
+aotContext->initLoadScopeObjectPropertyLookup(93);
+if (aotContext->engine->hasError()) {
+aotContext->setReturnValueUndefined();
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = double();
+}
+return;
+}
+}
+{
+}
+{
+}
+// generate_Ret
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = s.v2_0;
+}
+return;
+}
+ },{ 30, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
+    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
+    const auto *aotContext = &c;
+    Q_UNUSED(aotContext);
+    argTypes[0] = []() { static const auto t = QMetaType::fromName("QAccessible::Role"); return t; }();
+}, 
+    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
+Q_UNUSED(aotContext)
+Q_UNUSED(argv)
+// expression for role at line 171, column 13
+struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
+Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
+void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
+}
+const QQmlPrivate::AOTCompiledContext *aotContext;
+void **argv;
+int v2_2;
+};
+Storage s(aotContext, argv);
+aotContext->setLocals(&s);
+{
+}
+// generate_GetLookup
+#ifndef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+while (!aotContext->getEnumLookup(101, &s.v2_2)) {
+#ifdef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+aotContext->initGetEnumLookup(101, []() { static const auto t = QMetaType::fromName("QAccessible"); return t; }().metaObject(), "Role", "Graphic");
+if (aotContext->engine->hasError()) {
+aotContext->setReturnValueUndefined();
+if (argv[0]) {
+    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QAccessible::Role"); return t; }();
+    returnType.destruct(argv[0]);
+    returnType.construct(argv[0]);
+ }
+return;
+}
+}
+{
+}
+{
+}
+// generate_Ret
+if (argv[0]) {
+    const QMetaType returnType = QMetaType::fromType<int>();
+    returnType.destruct(argv[0]);
+    returnType.construct(argv[0], &s.v2_2);
+}
+return;
 }
  },{ 0, 0, nullptr, nullptr }};
 QT_WARNING_POP
